[![Gitter chat](http://img.shields.io/badge/gitter-join%20chat%20%E2%86%92-brightgreen.svg)](https://gitter.im/opentracing/public) [![Build Status](https://travis-ci.org/opentracing/basictracer-python.svg?branch=master)](https://travis-ci.org/opentracing/basictracer-python) [![PyPI version](https://badge.fury.io/py/basictracer.svg)](https://badge.fury.io/py/basictracer)

# Basictracer Python

A python version of the "BasicTracer" reference implementation for OpenTracing.
